PCB Environment: SignalContext Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
SignalContext Class Reference

`#include <Signals.hpp>`

## Public Member Functions
void | install (void(*handler_fptr)(int))
void | restore ()

## Detailed Description

Save signal handlers so we can intercept Ctrl-C while executing C++ code. Otherwise signals would only be delivered upon return to Python.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Signals.hpp